.. _pecan_routing:

:mod:`pecan.routing` -- Pecan Routing
=====================================

The :mod:`pecan.routing` module is the basis for all object-dispatch
routing in Pecan.

.. automodule:: pecan.routing
  :members:
  :show-inheritance: